==> huaweicloudsdkrds-3.0.49-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/recycle_policy_request_body.py <==
# coding: utf-8

import pprint
import re

import six





class RecyclePolicyRequestBody:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'recycle_policy': 'object'
    }

    attribute_map = {
        'recycle_policy': 'recycle_policy'
    }

    def __init__(self, recycle_policy=None):
        """RecyclePolicyRequestBody - a model defined in huaweicloud sdk"""
        
        

        self._recycle_policy = None
        self.discriminator = None

        self.recycle_policy = recycle_policy

    @property
    def recycle_policy(self):
        """Gets the recycle_policy of this RecyclePolicyRequestBody.

        每个元素都是与回收站相关信息。

        :return: The recycle_policy of this RecyclePolicyRequestBody.
        :rtype: object
        """
        return self._recycle_policy

    @recycle_policy.setter
    def recycle_policy(self, recycle_policy):
        """Sets the recycle_policy of this RecyclePolicyRequestBody.

        每个元素都是与回收站相关信息。

        :param recycle_policy: The recycle_policy of this RecyclePolicyRequestBody.
        :type: object
        """
        self._recycle_policy = recycle_policy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RecyclePolicyRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrds-3.0.52-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/recycle_policy_request_body.py <==
# coding: utf-8

import re
import six





class RecyclePolicyRequestBody:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'recycle_policy': 'object'
    }

    attribute_map = {
        'recycle_policy': 'recycle_policy'
    }

    def __init__(self, recycle_policy=None):
        """RecyclePolicyRequestBody - a model defined in huaweicloud sdk"""
        
        

        self._recycle_policy = None
        self.discriminator = None

        self.recycle_policy = recycle_policy

    @property
    def recycle_policy(self):
        """Gets the recycle_policy of this RecyclePolicyRequestBody.

        每个元素都是与回收站相关信息。

        :return: The recycle_policy of this RecyclePolicyRequestBody.
        :rtype: object
        """
        return self._recycle_policy

    @recycle_policy.setter
    def recycle_policy(self, recycle_policy):
        """Sets the recycle_policy of this RecyclePolicyRequestBody.

        每个元素都是与回收站相关信息。

        :param recycle_policy: The recycle_policy of this RecyclePolicyRequestBody.
        :type: object
        """
        self._recycle_policy = recycle_policy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RecyclePolicyRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
